@@ -159,7 +159,7 @@ def usage(commands, name, program):
                 help += parts[3]+' '
             else:
                 help += parts[0]+' '
-    help += 'SUB_COMMAND '
+    help += 'COMMAND '
     if name is not None:
         help += '[OPTIONS] '
         if commands[name].arg_spec:
@@ -214,7 +214,7 @@ def sub_command_options(commands, name, program):
         cur_opts += opt.get('options', [])
         rows.append((' '.join(cur_opts),  opt.get('help', '')))
     if rows:
-        help += "Sub-command '%s' options:\n"%name
+        help += "Command '%s' options:\n"%name
         help += two_cols(rows)
     return help
 
@@ -228,7 +228,7 @@ def sub_command_args(commands, name, program):
             arg_name = parts[0]
         rows.append((arg_name, parts[1]))
     if rows:
-        help += "Sub-command '%s' arguments:\n"%(name)
+        help += "Command '%s' arguments:\n"%(name)
         help += two_cols(rows)
     return help
 
@@ -244,7 +244,7 @@ def sub_commands(commands, name, program):
                 )
             )
     if rows:
-        help += 'Sub-commands:\n'
+        help += 'Commands:\n'
         help += two_cols(rows)
     return help
 
@@ -256,7 +256,7 @@ def tip(commands, name, program):
         else: 
             args = ' '+(' '.join([arg[0] for arg in commands[None].arg_spec]))
         help += (
-            '\nType `%(program)s%(args)s SUB_COMMAND --help\' ' 
+            '\nType `%(program)s%(args)s COMMAND --help\' ' 
             'for help on individual commands.'
         ) % {
            'program': program,
@@ -265,7 +265,7 @@ def tip(commands, name, program):
     else:
         help += (
             '\nType `%(program)s --help\' for a full list of '
-            'sub-commands.'
+            'commands.'
         ) % {
            'program': program,
         }
@@ -387,12 +387,25 @@ def process_command(cmd_line_parts, name, command):
     else:
         return cmd_args, main_opts
 
+help_option = dict(
+    options = ['-h', '--help'],
+    help = 'display this message'
+)
+
 class Cmd(object):
 
     #
     # Internal code
     #
 
+    default_aliases = {}
+
+    def __init__(self, name=None, aliases=None):
+        self.name = name
+        self.aliases = AttributeDict(self.default_aliases)
+        if aliases:
+            self.aliases.update(aliases)
+
     def on_initial_convert(self, service, option_spec, parsed_args, parsed_options):
         args = parsed_args
         processed = to_internal(option_spec, parsed_options)
@@ -441,14 +454,11 @@ class Cmd(object):
     arg_spec = []
 
     option_spec = {
-        'help': dict(
-            options = ['-h', '--help'],
-            help = 'display this message'
-        ),
+        'help': help_option
     }
 
     help = {
-        'summary': None,
+        'summary': 'No help summary specified',
     }
 
     def on_run(self, service, args, opts):
@@ -457,11 +467,13 @@ class Cmd(object):
     def on_config(self, service, args, opts, processed):
         return 0
 
+
+
 class LoggingCmd(Cmd):
 
     help = {
         'template': None,
-        'summary': 'start the current cost daemon'
+        'summary': 'No help summary specified'
     }
     option_spec = {
         'help': dict(
@@ -555,7 +567,7 @@ def handle_command(commands, cmd_line_parts=None, program=None, service=None):
             commands[sub_command],
         )
         if not hasattr(commands[sub_command], 'on_initial_convert'):
-            raise Exception('The sub-command for %r has no %r attribute'%(sub_command, 'on_initial_convert'))
+            raise Exception('The command for %r has no %r attribute'%(sub_command, 'on_initial_convert'))
         k, p, h = commands[sub_command].on_initial_convert(
             service, 
             commands[sub_command].option_spec, 
